@@ -1,10 +1,32 @@
 from io import BytesIO
 from django.http import HttpResponse
-from django.template.loader import get_template
+from django.template.loader import get_template,render_to_string
 
 from xhtml2pdf import pisa
 # import logging
 import datetime
+from django.core.mail import EmailMultiAlternatives
+from django.utils.html import strip_tags
+
+def SendMail(subject='',message_body='',sender='',recipient_list=[],attachment_list=[],template_data={},is_html_msg=True):
+    if template_data:
+        html_body=render_to_string(template_data.path,template_data.context)
+        text_body=strip_tags(html_body)
+        is_html_msg=True
+    elif is_html_msg:
+        html_body=message_body
+        text_body=strip_tags(message_body)
+    else:
+        text_body=message_body
+    if sender=='':
+        msg=EmailMultiAlternatives(subject=subject,body=text_body,to=recipient_list)
+    else:
+        msg = EmailMultiAlternatives(subject, text_body,sender, recipient_list)
+    if is_html_msg:
+        msg.attach_alternative(html_body,"text/html")
+    for x in attachment_list:
+        msg.attach(x.name,x.content)
+    msg.send()
 
 
 def render_to_pdf(template_src, context_dict={}):
